pub enum TIP20FactoryError {
AddressReserved(AddressReserved),
AddressNotReserved(AddressNotReserved),
InvalidQuoteToken(InvalidQuoteToken),
TokenAlreadyExists(TokenAlreadyExists),
}Expand description
Container for all the ITIP20Factory custom errors.
Variants
AddressReserved(AddressReserved)
AddressNotReserved(AddressNotReserved)
InvalidQuoteToken(InvalidQuoteToken)
TokenAlreadyExists(TokenAlreadyExists)
Implementations
Sourceimpl ITIP20FactoryErrors
impl ITIP20FactoryErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl ITIP20FactoryErrors
impl ITIP20FactoryErrors
Sourcepub const fn address_reserved() -> ITIP20FactoryErrors
pub const fn address_reserved() -> ITIP20FactoryErrors
Creates an error when attempting to use a reserved address.
Sourcepub const fn address_not_reserved() -> ITIP20FactoryErrors
pub const fn address_not_reserved() -> ITIP20FactoryErrors
Creates an error when address is not in the reserved range.
Sourcepub const fn invalid_quote_token() -> ITIP20FactoryErrors
pub const fn invalid_quote_token() -> ITIP20FactoryErrors
Creates an error for invalid quote token.
Sourcepub const fn token_already_exists(token: Address) -> ITIP20FactoryErrors
pub const fn token_already_exists(token: Address) -> ITIP20FactoryErrors
Creates an error when token already exists at the given address.